@@ -51,6 +51,9 @@ DataProcessingAdditionalGroup = [
     cfg.StrOpt('test_ssh_user',
                default='ubuntu',
                help='username used to access the test image.'),
+    cfg.BoolOpt('use_api_v2',
+                default=False,
+                help='Run API tests against APIv2 instead of 1.1'),
     cfg.StrOpt('api_version_saharaclient',
                default='1.1',
                help='Version of Sahara API used by saharaclient',
